@@ -3,13 +3,19 @@
 #*#    in demo03sonar_B.r:    tdm$nExperim=2; tdm$nrun=5;
 #*#    and in sonar_05.conf:  auto.loop.nevals = 50; init.design.size = 10;
 #*# and with two tuners SPOT and LHD in comparison.
+#*#
+#*# This demo may not run under RStudio (incompatibility plotting device), but will run in
+#*# R console. 
 
 ## load package and set working directory (dir with .apd, .conf and main_*.r file)
 path <- paste(find.package("TDMR"), "demo02sonar",sep="/");
 #path <- paste("../inst", "demo02sonar",sep="/");
 
+oldwd <- getwd();  setwd(path);
+source("main_sonar.r");    # from working dir
+
 ## preliminary settings for TDMR
-tdm <- list( mainFunc="main_sonar"
+tdm <- list( mainFile="main_sonar.r"
             , runList = "sonar_05.conf"
             , umode=c("RSUB")           # ["CV" | "RSUB" | "TST" | "SP_T" ]
             , tuneMethod = c("spot","lhd")
@@ -17,12 +23,12 @@ tdm <- list( mainFunc="main_sonar"
             , nrun=5, nfold=2         # repeats and CV-folds for the unbiased runs
             , nExperim=2
             , parallelCPUs=1
-            , parallelFuncs="readCmdSonar"  # fct's to export in addition to tdm$mainFunc in case parallelCPUs>1
+            , parallelFuncs="readTrnSonar"  # fct's to export in addition to tdm$mainFunc in case parallelCPUs>1
             , optsVerbosity = 0       # the verbosity for the unbiased runs
             );
 ## tdm$runList="sonar_05.conf" has the settings for the tuning process (e.g. 
-##    - "auto.loop.steps"=number of SPOT generations       
-##    - "auto.loop.evals"=budget of model building runs and 
+##    - auto.loop.steps = number of SPOT generations       
+##    - auto.loop.evals = budget of model building runs and 
 ##    - io.roiFileName = "sonar_05.roi"
 ## ). tdm$runList could contain other files as well (e.g. 
 ##    c("sonar_01.conf","sonar_02.conf","sonar_03.conf")
@@ -34,6 +40,6 @@ source(paste(path,tdm$mainFile,sep="/"));
 source(paste(path,"start_bigLoop.r",sep="/"),chdir=TRUE);    # change dir to 'path' while sourcing
 
 ## the resulting tuning surface (the metamodel) can be inspected interactively with
-##      tdmEnvTLoad(paste(path,tdm$filenameEnvT,sep="/"));     
+##      envT <- tdmEnvTLoad(paste(path,tdm$filenameEnvT,sep="/"));     
 ##      tdmPlotResMeta(envT);
-## (tdmEnvTLoad(...) is only needed for reloading envT in another R-session)
+## (tdmEnvTLoad(...) is only needed for reloading envT in another R-session) 
