@@ -1,4 +1,5 @@
 opts= tdmOptsDefaultsSet();
-tdm = list(umode="RSUB");
+tdm = list(umode="RSUB",runList="");
 data(iris);
 dataObj=tdmSplitTestData(opts,tdm,dset=iris);
+print(dataObj)
