@@ -100,10 +100,12 @@ source.tdm <- function(tdmPath, tdmParallelCPUs=1,theSpotPath=NA,theRsfaPath=NA)
     source(createSourcePath("tdmParaBootstrap.r"))
     source(createSourcePath("tdmPreprocUtils.r"))
     source(createSourcePath("tdmReadData.r"))
+    source(createSourcePath("tdmReadData2.r"))
     source(createSourcePath("tdmRegress.r"))
     source(createSourcePath("tdmRegressLoop.r"))
 
     source(createSourcePath("tdmBigLoop.r"))
+    source(createSourcePath("tdmTuneIt.r"))
     source(createSourcePath("tdmDefaultsFill.r"))
     source(createSourcePath("tdmDispatchTuner.r"))
     source(createSourcePath("tdmEnvTMakeNew.r"))
